@@ -21,6 +21,13 @@ filterRandom <- function(.data, n, sample_size) {
     mc <- match.call()
     dataname <- mc$.data
 
+    is_survey <- is_survey(.data)
+    if (is_survey) {
+        stop("Survey data cannot be randomly filtered at this stage.")
+        # .data <- srvyr::as_survey(.data)
+        # dataname <- glue::glue("{dataname} %>% srvyr::as_survey()")
+    }
+
     exp <- ~ .DATA %>%
         dplyr::sample_n(.SAMPLE_SIZE * .Nx, replace = FALSE) %>%
         dplyr::mutate(Sample.Number = factor(rep(1:.Nx, each = .SAMPLE_SIZE)))
